@@ -24,6 +24,28 @@ OC.L10N.register(
     "Archived messages are moved in:" : "Arkiverede meddelser flyttes til:",
     "Snoozed messages are moved in:" : "Udsatte beskeder flyttes ind:",
     "Junk messages are saved in:" : "Uønsket beskeder gemmes i:",
+    "Connecting" : "Tilslutter",
+    "Reconnect Google account" : "Gentilslut Google-kontoen",
+    "Sign in with Google" : "Log ind med Google",
+    "Reconnect Microsoft account" : "Gentilslut Microsoft-konto",
+    "Save" : "Gem",
+    "Connect" : "Tilslut",
+    "Looking up configuration" : "Søger konfiguration",
+    "Checking mail host connectivity" : "Kontrollerer mailværtens forbindelse",
+    "Configuration discovery failed. Please use the manual settings" : "Opdagelse af konfiguration mislykkedes. Brug venligst de manuelle indstillinger",
+    "Password required" : "Adgangskode krævet",
+    "Testing authentication" : "Test af autentificering",
+    "Awaiting user consent" : "Afventer brugerens samtykke",
+    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto oprettet. Følg venligst pop-up-instruktionerne for at linke din Google-konto.",
+    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto opdateret. Følg venligst pop-up-instruktionerne for at genoprette forbindelsen til din Google-konto.",
+    "Account updated" : "Konto opdateret",
+    "IMAP server is not reachable" : "IMAP server er ikke tilgængelig",
+    "SMTP server is not reachable" : "SMTP server er ikke tilgængelig",
+    "IMAP username or password is wrong" : "IMAP brugernavn eller kodeord er forkert",
+    "SMTP username or password is wrong" : "SMTP brugernavn eller kodeord er forkert",
+    "IMAP connection failed" : "IMAP-forbindelse mislykkedes",
+    "SMTP connection failed" : "SMTP-forbindelse mislykkedes",
+    "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
     "Auto" : "Auto",
     "Name" : "Navn",
     "Mail address" : "Mail addresse",
@@ -47,38 +69,16 @@ OC.L10N.register(
     "SMTP User" : "SMTP bruger",
     "SMTP Password" : "SMTP kodeord",
     "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For at din Google-konto skal kunne fungere med denne app, skal du aktivere to-faktor-godkendelse for Gmail samt generere en App-specifik adgangskode.",
-    "Connecting" : "Tilslutter",
-    "Reconnect Google account" : "Gentilslut Google-kontoen",
-    "Sign in with Google" : "Log ind med Google",
-    "Reconnect Microsoft account" : "Gentilslut Microsoft-konto",
-    "Save" : "Gem",
-    "Connect" : "Tilslut",
-    "Looking up configuration" : "Søger konfiguration",
-    "Checking mail host connectivity" : "Kontrollerer mailværtens forbindelse",
-    "Configuration discovery failed. Please use the manual settings" : "Opdagelse af konfiguration mislykkedes. Brug venligst de manuelle indstillinger",
-    "Password required" : "Password påkrævet",
-    "Testing authentication" : "Test af autentificering",
-    "Awaiting user consent" : "Afventer brugerens samtykke",
-    "Account created. Please follow the pop-up instructions to link your Google account" : "Konto oprettet. Følg venligst pop-up-instruktionerne for at linke din Google-konto.",
-    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konto opdateret. Følg venligst pop-up-instruktionerne for at genoprette forbindelsen til din Google-konto.",
-    "Account updated" : "Konto opdateret",
-    "IMAP server is not reachable" : "IMAP server er ikke tilgængelig",
-    "SMTP server is not reachable" : "SMTP server er ikke tilgængelig",
-    "IMAP username or password is wrong" : "IMAP brugernavn eller kodeord er forkert",
-    "SMTP username or password is wrong" : "SMTP brugernavn eller kodeord er forkert",
-    "IMAP connection failed" : "IMAP-forbindelse mislykkedes",
-    "SMTP connection failed" : "SMTP-forbindelse mislykkedes",
-    "There was an error while setting up your account" : "Der opstod en fejl under opsætning af din konto",
     "Account settings" : "Kontoindstillinger",
     "Aliases" : "Aliases",
     "Signature" : "Underskrift",
     "A signature is added to the text of new messages and replies." : "En signatur tilføjes til teksten i nye meddelelser og svar.",
-    "Writing mode" : "Skrivemåde",
+    "Writing mode" : "Skrivestil",
     "Preferred writing mode for new messages and replies." : "Foretrukken skrivemåde for nye meddelelser og svar.",
     "Default folders" : "Standardmapper",
     "Autoresponder" : "Autosvar",
-    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst én gang hver 4. dag.",
-    "Please connect to a sieve server first." : "Opret forbindelse til en sieve server først.",
+    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst en gang hver 4. dag.",
+    "Filters" : "Filtre",
     "Mail server" : "Mail server",
     "Update alias" : "Opdater alias",
     "Show update alias form" : "Vis formular til opdateringsalias",
@@ -88,7 +88,9 @@ OC.L10N.register(
     "Email address" : "Email adresse",
     "Add alias" : "Tilføj alias",
     "Create alias" : "Opret alias",
-    "Cancel" : "Annullér",
+    "Cancel" : "Annuller",
+    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
+    "Could not update preference" : "Præference kunne ikke opdateres",
     "Mail settings" : "Mail indstillinger",
     "Accounts" : "Konti",
     "Add mail account" : "Tilføj mail konto",
@@ -97,24 +99,32 @@ OC.L10N.register(
     "Sorting" : "Sortering",
     "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
     "Register as application for mail links" : "Registrer som program til at åbne mail links",
-    "Register" : "Registér",
+    "Register" : "Register",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
     "Trusted senders" : "Betroede afsendere",
     "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
     "Looking for a way to encrypt your emails?" : "Leder du efter en måde at kryptere dine e-mails på?",
+    "About" : "Om",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Compose new message" : "Skriv en ny meddelelse",
     "Newer message" : "Nyere besked",
     "Older message" : "Ældre besked",
     "Toggle star" : "Toggle stjerne",
     "Toggle unread" : "Toggle læst",
-    "Archive" : "Arkivér",
+    "Archive" : "Arkiver",
     "Delete" : "Slet",
     "Search" : "Søg",
     "Send" : "Send",
-    "Refresh" : "Opdatér",
-    "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
-    "Could not update preference" : "Præference kunne ikke opdateres",
+    "Refresh" : "Opdater",
+    "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
+    "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
+    "Send later" : "Send senere",
+    "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
+    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME blev valgt, men vi har ikke et certifikat for det valgte alias. Beskeden bliver ikke underskrevet eller krypteret.",
+    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Enhver eksisterende formatering (f.eks. fed, kursiv, understregning eller indlejrede billeder) vil blive fjernet.",
+    "Turn off formatting" : "Slå formatering fra",
+    "Turn off and remove formatting" : "Sluk og fjern formatering",
+    "Keep formatting" : "Behold formattering",
     "From" : "Fra",
     "Select account" : "Vælg konto",
     "To" : "Til",
@@ -132,40 +142,39 @@ OC.L10N.register(
     "Error saving draft" : "Fejl ved lagring af kladde",
     "Draft saved" : "Kladde gemt",
     "Save draft" : "Gem kladde",
-    "Discard & close draft" : "Kassér og luk kladde",
+    "Discard & close draft" : "Kasser og luk kladde",
     "Enable formatting" : "Aktiver formatering",
     "Disable formatting" : "Deaktiver formatering",
     "Upload attachment" : "Upload vedhæftning",
     "Add attachment from Files" : "Vedhæft fra filer",
     "Smart picker" : "Smart Vælger",
-    "Send later" : "Send senere",
     "Request a read receipt" : "Anmod om en læsekvittering",
     "Sign message with S/MIME" : "Underskriv besked med S/MIME",
     "Encrypt message with S/MIME" : "Krypter besked med S/MIME",
-    "Encrypt message with Mailvelope" : "Kryptér meddelelse med Mailvelope",
+    "Encrypt message with Mailvelope" : "Krypter meddelelse med Mailvelope",
     "Send now" : "Send nu",
     "Tomorrow morning" : "I morgen tidlig",
     "Tomorrow afternoon" : "I morgen eftermiddag",
     "Monday morning" : "Mandag morgen",
     "Custom date and time" : "Brugerdefineret dato og tid",
     "Enter a date" : "Indtast en dato",
-    "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
-    "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
-    "Message {id} could not be found" : "Beskeden {id} kunne ikke findes",
-    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Signer eller krypter med S/MIME blev valgt, men vi har ikke et certifikat for det valgte alias. Beskeden bliver ikke underskrevet eller krypteret.",
-    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Enhver eksisterende formatering (f.eks. fed, kursiv, understregning eller indlejrede billeder) vil blive fjernet.",
-    "Turn off formatting" : "Slå formatering fra",
-    "Turn off and remove formatting" : "Sluk og fjern formatering",
-    "Keep formatting" : "Behold formattering",
+    "Choose" : "Vælg",
     "Choose a file to add as attachment" : "Vælg en fil, der skal tilføjes som vedhæftning",
     "Choose a file to share as a link" : "Vælg en fil der skal deles som link",
-    "Choose" : "Vælg",
     "_{count} attachment_::_{count} attachments_" : ["{count} vedhæftet fil","{count} vedhæftede filer"],
     "Confirm" : "Bekræft",
     "Plain text" : "Klartekst",
     "Rich text" : "Formateret tekst",
     "No messages in this mailbox" : "Ingen beskeder i denne postkasse",
     "No messages" : "Ingen beskeder",
+    "Blind copy recipients only" : "Kun blinde kopi-modtagere",
+    "No subject" : "Intet emne",
+    "Set reminder for later today" : "Sæt påmindelse for senere i dag",
+    "Set reminder for tomorrow" : "Sæt påmindelse for i morgen",
+    "Set reminder for this weekend" : "Sæt påmindelse for denne weekend",
+    "Set reminder for next week" : "Sæt påmindelse for næste weekend",
+    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
+    "Could not delete message" : "Kunne ikke slette beskeden",
     "Draft: " : "Kladde:",
     "This message is unread" : "Denne besked er ulæst",
     "Unfavorite" : "U-favorit",
@@ -173,9 +182,9 @@ OC.L10N.register(
     "Unread" : "Ulæst",
     "Read" : "Læst",
     "Unimportant" : "Ikke vigtig",
-    "Mark not spam" : "Markér ikke spam",
+    "Mark not spam" : "Marker ikke spam",
     "Mark as spam" : "Marker som spam",
-    "Edit tags" : "Redigér mærker",
+    "Edit tags" : "Rediger mærker",
     "Move thread" : "Flyt tråden",
     "Delete thread" : "Slet tråd",
     "More actions" : "Flere handlinger",
@@ -184,26 +193,27 @@ OC.L10N.register(
     "Create event" : "Opret begivenhed",
     "Create task" : "Opret opgave",
     "Download message" : "Download besked",
-    "Blind copy recipients only" : "Kun blinde kopi-modtagere",
-    "No subject" : "Intet emne",
-    "No trash mailbox configured" : "Der er ikke konfigureret nogen papirkurvspostkasse",
-    "Could not delete message" : "Kunne ikke slette beskeden",
     "Load more" : "Hent flere",
-    "_Mark {number} read_::_Mark {number} read_" : ["Marker {number} læst","Marker {number} læst"],
+    "_Mark {number} read_::_Mark {number} read_" : ["Marker {number} læst","Marker {number} som læst"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Marker {number} som ulæst","Marker {number} som ulæst"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Marker {number} som vigtigt","Marker {number} som vigtigt"],
     "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Marker {number} som uvigtig","Marker {number} som uvigtig"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Fjern foretrukken {number}","Fjern foretrukken {number}"],
-    "_Favorite {number}_::_Favorite {number}_" : ["Favorit {number}","Favorit {number}"],
+    "_Favorite {number}_::_Favorite {number}_" : ["Favorit {number}","Favoriser {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["Fravælg {number}","Fravælg {number}"],
     "_Move {number} thread_::_Move {number} threads_" : ["Flyt {number} tråd","Flyt {number} tråde"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedhæftet fil","Videresend {number} som vedhæftet fil"],
     "Report this bug" : "Rapporter denne fejl",
+    "Event created" : "Begivenhed oprettet",
+    "Could not create event" : "Begivenheden kunne ikke oprettes",
     "All day" : "Hele dagen",
     "Description" : "Beskrivelse",
     "Create" : "Opret",
-    "Event created" : "Begivenhed oprettet",
-    "Could not create event" : "Begivenheden kunne ikke oprettes",
+    "This event was updated" : "Denne begivenhed blev opdateret",
+    "{attendeeName} accepted your invitation" : "{attendeeName} accepterede din invitation",
+    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} accepterede foreløbigt din invitation",
+    "{attendeeName} declined your invitation" : "{attendeeName} afviste din invitation",
+    "{attendeeName} reacted to your invitation" : "{attendeeName} reagerede på din invitation",
     "You accepted this invitation" : "Du accepterede denne invitation",
     "You tentatively accepted this invitation" : "Du accepterede foreløbigt denne invitation",
     "You declined this invitation" : "Du afviste denne invitation",
@@ -212,17 +222,11 @@ OC.L10N.register(
     "This event was cancelled" : "Denne begivenhed blev aflyst",
     "Save to" : "Gem til",
     "Select" : "Vælg",
-    "Comment" : "Kommentér",
+    "Comment" : "Kommenter",
     "Accept" : "Accepter",
     "Decline" : "Afvis",
     "Tentatively accept" : "Accepter foreløbigt",
     "More options" : "Flere muligheder",
-    "This event is in the past." : "Denne begivenhed er i fortiden.",
-    "This event was updated" : "Denne begivenhed blev opdateret",
-    "{attendeeName} accepted your invitation" : "{attendeeName} accepterede din invitation",
-    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} accepterede foreløbigt din invitation",
-    "{attendeeName} declined your invitation" : "{attendeeName} afviste din invitation",
-    "{attendeeName} reacted to your invitation" : "{attendeeName} reagerede på din invitation",
     "Remove" : "Fjern",
     "email" : "e-mail",
     "Could not open mailbox" : "Postkassen kunne ikke åbnes",
@@ -230,63 +234,69 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksering af dine beskeder. Dette kan tage lidt længere tid for større postkasser.",
     "Choose target mailbox" : "Vælg målpostkasse",
     "No more submailboxes in here" : "Ikke flere underpostkasser herinde",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "Important info" : "Vigtig information",
     "Other" : "Andet",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Beskeder vil automatisk blive markeret som vigtige baseret på, hvilke meddelelser du har interageret med eller markeret som vigtige. I begyndelsen skal du muligvis manuelt ændre vigtigheden for at lære systemet, men det vil forbedres med tiden.",
     "The sender of this message has asked to be notified when you read this message." : "Afsenderen af denne besked har bedt om at blive underrettet, når du læser denne besked.",
     "Forward" : "Videresend",
     "Move message" : "Flyt besked",
+    "Translate" : "Oversæt",
     "Forward message as attachment" : "Videresend besked som vedhæftet fil",
     "View source" : "Vis kildekode",
+    "Unnamed" : "Unavngiven",
+    "Embedded message" : "Indlejret besked",
     "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
     "Import into calendar" : "Importere til kalender",
     "Download attachment" : "Hent vedhæftning",
     "Save to Files" : "Gem til filer",
-    "Unnamed" : "Unavngiven",
-    "Embedded message" : "Indlejret besked",
     "Choose a folder to store the attachments in" : "Vælg den mappe, hvor vedhæftningerne skal gemmes i",
     "Save all to Files" : "Gem alle filer",
     "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
     "Show images" : "Vis billeder",
     "Move" : "Flyt",
+    "Loading …" : "Indlæser…",
+    "Remove account" : "Fjern konto",
+    "Remove {email}" : "Fjern {email}",
     "Quota" : "Kvote",
     "Show only subscribed mailboxes" : "Vis kun postkasser der abonneres på",
     "Add mailbox" : "Tilføj postkasse",
     "Saving" : "Gemmer",
     "Move up" : "Flyt op",
     "Move down" : "Flyt ned",
-    "Remove account" : "Fjern konto",
-    "Loading …" : "Indlæser…",
-    "Remove {email}" : "Fjern {email}",
     "Show all subscribed mailboxes" : "Vis alle postkasser der abonneres på",
     "Show all mailboxes" : "Vis alle postkasser",
     "Collapse mailboxes" : "Skjul postkasser ",
-    "Mark all as read" : "Markér alle som læst",
-    "Mark all messages of this mailbox as read" : "Markér alle beskeder i denne postkasse som læst",
+    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
+    "Clear mailbox {name}" : "Ryd postkasse {name}",
+    "Clear mailbox" : "Ryd postkasse",
+    "Mark all as read" : "Marker alle som læst",
+    "Mark all messages of this mailbox as read" : "Marker alle beskeder i denne postkasse som læst",
     "Add submailbox" : "Tilføj underpostkasse",
     "Rename" : "Omdøb",
     "Clear cache" : "Ryd cache",
     "Subscribed" : "Abonneret",
     "Sync in background" : "Synkroniser i baggrunden",
-    "Clear mailbox" : "Ryd postkasse",
-    "Clear mailbox {name}" : "Ryd postkasse {name}",
-    "_{total} message_::_{total} messages_" : ["{total} besked","{total} beskeder"],
     "Outbox" : "Udbakke",
     "New message" : "Ny besked",
+    "Draft" : "Kladde",
+    "Reply" : "Besvar",
+    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
     "Error sending your message" : "Fejl ved afsendelse af din besked",
     "Retry" : "Prøv igen",
     "Uploading attachments …" : "Uploader vedhæftninger",
     "Sending …" : "Sender ...",
     "Warning sending your message" : "Advarsel om at sende din besked",
     "Send anyway" : "Send alligevel",
-    "Reply" : "Besvar",
-    "No sent mailbox configured. Please pick one in the account settings." : "Ingen sendt postkasse konfigureret. Vælg en i kontoindstillingerne.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
+    "Welcome to {productName} Mail" : "Velkommen til {productName} mail",
+    "Start writing a message by clicking below or select an existing message to display its contents" : "Begynd at skrive en besked ved at klikke nedenfor eller vælg en eksisterende besked for at få vist dens indhold",
     "First day" : "Første dag",
     "Message" : "Besked",
     "Could not open outbox" : "Kunne ikke åbne udbakken",
+    "New Contact" : "Ny kontakt",
     "Copy to clipboard" : "Kopier til udklipsholder",
     "Add" : "Tilføj",
+    "Clear" : "Ryd",
     "Search in mailbox" : "Søg i postkasse",
     "Close" : "Luk",
     "Search parameters" : "Søgeparametre",
@@ -298,32 +308,40 @@ OC.L10N.register(
     "Select tags" : "Vælg tags",
     "Marked as" : "Markeret som",
     "Has attachments" : "Har vedhæftede filer",
+    "Mentions me" : "Omtalte mig",
     "Last 7 days" : "Sidste 7 dage",
-    "Clear" : "Ryd",
-    "Custom" : "Valgfrit",
+    "Sieve credentials" : "Sieve legitimationsoplysninger",
+    "IMAP credentials" : "IMAP legitimationsoplysninger",
+    "Custom" : "Brugerdefineret",
     "Signature …" : "Underskrift …",
     "Save signature" : "Gem underskrift",
-    "Add tag" : "Tilføj Tag",
+    "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
+    "Add tag" : "Tilføj Tag",
     "Loading thread" : "Indlæser tråd",
     "Not found" : "Ikke fundet",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Reply all" : "Besvar alle",
     "Reply to sender only" : "Besvar kun afsender",
     "Mark as unread" : "Marker som ulæst",
     "Mark as read" : "Marker som læst",
     "Delete message" : "Slet besked",
     "Message source" : "Beskedens kildekode",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
-    "(organizer)" : "(arrangør)",
+    "Go to newest message" : "Gå til nyeste besked",
+    "Copy translated text" : "Kopier oversat tekst",
     "Untitled event" : "Unavngiven begivenhed",
-    "Airplane" : "Fly",
+    "(organizer)" : "(arrangør)",
     "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
-    "Train" : "Tog",
+    "Airplane" : "Fly",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
+    "Train" : "Tog",
+    "New filter" : "Nyt filter",
     "Operator" : "Operatør",
+    "New test" : "Nyeste test",
     "Actions" : "Handlinger",
+    "New action" : "Ny handling",
     "Priority" : "Prioritet",
     "Reset" : "Nulstil",
     "Client ID" : "Klient-ID",
@@ -333,6 +351,10 @@ OC.L10N.register(
     "Host" : "Vært",
     "Port" : "Port",
     "SMTP" : "SMTP",
+    "Failed to import the certificate. Please check the password." : "Kunne ikke importere certifikatet. Tjek venligst adgangskoden.",
+    "Certificate imported successfully" : "Certifikatet blev importeret",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kunne ikke importere certifikatet. Sørg for, at den private nøgle matcher certifikatet og ikke er beskyttet af en kode.",
+    "Failed to import the certificate" : "Kunne ikke importere certifikatet",
     "S/MIME certificates" : "S/MIME certifikater",
     "Certificate name" : "Certifikatnavn",
     "E-mail address" : "E-mail adresse",
@@ -347,10 +369,6 @@ OC.L10N.register(
     "Private key (optional)" : "Privat nøgle (valgfrit)",
     "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøgle er kun påkrævet, hvis du har til hensigt at sende signerede og krypterede e-mails ved hjælp af dette certifikat.",
     "Submit" : "Tilføj",
-    "Failed to import the certificate. Please check the password." : "Kunne ikke importere certifikatet. Tjek venligst adgangskoden.",
-    "Certificate imported successfully" : "Certifikatet blev importeret",
-    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kunne ikke importere certifikatet. Sørg for, at den private nøgle matcher certifikatet og ikke er beskyttet af en kode.",
-    "Failed to import the certificate" : "Kunne ikke importere certifikatet",
     "Account connected" : "Kontoen er tilknyttet",
     "Connect your mail account" : "Forbind din mail konto",
     "All" : "Alle",
@@ -366,6 +384,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{fra}\n{emne}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny besked \nfra {from}","%n nye beskeder \nfra {from}"],
     "Nextcloud Mail" : "Nextcloud Mail",
+    "Discard changes" : "Fortryd ændringer",
     "Message sent" : "Beskeden blev sendt",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
@@ -378,8 +397,6 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
-    "Sieve filter rules" : "Sieve filter regler",
-    "Sieve filter server" : "Sigt filter server",
-    "Unselect" : "Fravælg"
+    "This event is in the past." : "Denne begivenhed er i fortiden."
 },
 "nplurals=2; plural=(n != 1);");
