@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Later" : "Después",
     "Mail" : "Correo",
+    "Connecting" : "Conectando",
+    "Save" : "Guardar",
+    "Connect" : "Conectar",
+    "Password required" : "Se requiere contraseña",
     "Name" : "Nombre",
     "Mail address" : "Dirección de correo",
     "Password" : "Contraseña",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Connecting" : "Conectando",
-    "Save" : "Guardar",
-    "Connect" : "Conectar",
-    "Password required" : "Se requiere contraseña",
     "Aliases" : "Aliases",
     "Signature" : "Firma",
     "Go back" : "Regresar",
@@ -31,6 +31,7 @@ OC.L10N.register(
     "Cancel" : "Cancelar",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
+    "Sorting" : "Orden",
     "Register" : "Registrar",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Compose new message" : "Redactar nuevo mensaje",
@@ -44,8 +45,8 @@ OC.L10N.register(
     "Select account" : "Seleccione la cuenta",
     "Subject" : "Asunto",
     "Add attachment from Files" : "Agregar adjunto desde Archivos",
-    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Choose" : "Elige",
+    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
     "Confirm" : "Confirmar",
     "Favorite" : "Favorito",
     "Read" : "Leer",
@@ -63,34 +64,35 @@ OC.L10N.register(
     "email" : "correo electrónico",
     "Other" : "Otro",
     "Forward" : "Reenviar",
+    "Translate" : "Traducir",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
-    "Unnamed" : "Sin nombre",
     "Save all to Files" : "Guardar todos a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
     "Move" : "Mover",
+    "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
-    "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Limpiar caché",
     "New message" : "Mensaje nuevo",
+    "Reply" : "Responder",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
-    "Reply" : "Responder",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Añadir",
+    "Clear" : "Borrar",
     "Close" : "Cerrar",
     "Date" : "Fecha",
     "Tags" : "Etiquetas",
-    "Clear" : "Borrar",
     "Custom" : "Personalizado",
-    "Add tag" : "Añadir etiqueta",
     "Tag already exists" : "La etiqueta ya existe",
+    "Add tag" : "Añadir etiqueta",
     "Not found" : "No encontrado",
     "Operator" : "Operador",
     "Actions" : "Acciones",
