@@ -2,12 +2,17 @@ OC.L10N.register(
     "mail",
     {
     "Important mail" : "Mail important",
+    "No message found yet" : "Pas cap de messatge trobat",
     "Unread mail" : "Mail pas legit",
     "Important" : "Important",
     "Work" : "Professional(a)",
     "Personal" : "Personal",
-    "Mails" : "Mails",
     "Mail" : "Mail",
+    "Mails" : "Mails",
+    "Connecting" : "Connexion",
+    "Save" : "Salvar",
+    "Connect" : "Connectar",
+    "Password required" : "Senhal requerit",
     "Name" : "Nom",
     "Password" : "Senhal",
     "IMAP Settings" : "Paramètres IMAP",
@@ -17,69 +22,82 @@ OC.L10N.register(
     "IMAP Password" : "Senhal IMAP",
     "SMTP Settings" : "Paramètres SMTP",
     "SMTP Password" : "Senhal SMTP",
-    "Connecting" : "Connexion",
-    "Save" : "Salvar",
-    "Connect" : "Connectar",
     "Account settings" : "Paramètres de compte",
     "Signature" : "Signatura",
     "Mail server" : "Servidor email",
+    "Rename alias" : "Renomenar l’àlias",
+    "Go back" : "Revenir en arrière",
     "Email address" : "Adreça mail",
     "Cancel" : "Anullar",
+    "General" : "Generals",
+    "List" : "Tièra",
+    "Register" : "S'inscriure",
+    "About" : "A prepaus",
+    "Keyboard shortcuts" : "Acorchis de clavièr",
+    "Archive" : "Archius",
+    "Delete" : "Suprimir",
+    "Search" : "Recercar",
+    "Send" : "Mandar",
+    "Refresh" : "Refrescar",
     "From" : "De",
     "Write message …" : "Escriure un messatge…",
     "Monday morning" : "Diluns matin",
-    "Sending …" : "Mandadís…",
-    "Go back" : "Revenir en arrière",
-    "Retry" : "Tornar ensajar",
-    "Message sent!" : "Messatge mandat !",
-    "Send" : "Mandar",
+    "Choose" : "Causir",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
-    "No message found yet" : "Pas cap de messatge trobat",
+    "Confirm" : "Confirmar",
+    "No messages" : "Cap de messatge",
+    "Tomorrow – {timeLocale}" : "Deman – {timeLocale}",
     "Favorite" : "Favorit",
     "Read" : "Legit",
-    "Select" : "Select",
-    "Move" : "Move",
     "More actions" : "Mai d’accions",
+    "Back" : "Retorn",
     "All day" : "Tota la jornada",
+    "Description" : "Descripcion",
     "Create" : "Crear",
+    "Select" : "Select",
     "Comment" : "Comentaris",
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
-    "Choose" : "Causir",
+    "Remove" : "Suprimir",
     "Other" : "Autre",
-    "Reply" : "Respondre",
+    "Translate" : "Tradurre",
     "Choose a folder to store the attachment in" : "Causissètz lo dorsièr dins lo qual enregistrar la pèça junta",
-    "Quota" : "Quota",
+    "Move" : "Move",
     "Loading …" : "Cargament…",
-    "Mark all as read" : "Marcar totes coma legits",
-    "Edit name" : "Modificar lo nom",
-    "Clear cache" : "Voidar l'escondedor",
+    "Quota" : "Quota",
     "_{total} message_::_{total} messages_" : ["{total} messatge","{total} messatges"],
-    "Delete" : "Suprimir",
+    "Mark all as read" : "Marcar totes coma legits",
+    "Rename" : "Tornar nommar",
+    "Clear cache" : "Voidar l'escondedor",
+    "Reply" : "Respondre",
+    "Retry" : "Tornar ensajar",
+    "Sending …" : "Mandadís…",
     "Copy to clipboard" : "Copiar dins lo quichapapièrs",
     "Add" : "Apondre",
-    "Tags" : "Etiquetas",
     "Clear" : "Escafar",
-    "Search" : "Recercar",
+    "Close" : "Tampar",
+    "Body" : "Còs",
     "Date" : "Data",
-    "Disabled" : "Desactivat",
-    "Enabled" : "Activada",
+    "Tags" : "Etiquetas",
     "Custom" : "Personalizats",
     "Mark as unread" : "Marcar coma pas legit",
     "Mark as read" : "Marcar coma legit",
-    "Remove" : "Suprimir",
+    "Translate message" : "Traduire lo messatge",
+    "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
     "Train" : "Tren",
+    "Flag" : "Drapèu",
+    "Actions" : "Accions",
     "Reset" : "Reïnicializar",
-    "General" : "Generals",
+    "Client ID" : "ID client",
     "User" : "User",
     "Host" : "Òste",
     "Port" : "Pòrt",
-    "Keyboard shortcut" : "Acorchis de clavièr",
-    "Keyboard shortcuts" : "Acorchis de clavièr",
-    "Refresh" : "Refrescar",
+    "Valid until" : "Valid fins a",
+    "Certificate" : "Certificat",
+    "Submit" : "Transmetre",
+    "Account connected" : "Compte connectat",
     "All" : "Tot",
-    "Archive" : "Archius",
     "Drafts" : "Borrolhons",
     "Favorites" : "Favorits",
     "All inboxes" : "Totas las bóstias",
