@@ -17,6 +17,8 @@ OC.L10N.register(
     "Drafts are saved in:" : "Is brutacòpias sunt sarvadas in:",
     "Sent messages are saved in:" : "Is messàgios imbiados sunt sarvados in:",
     "Deleted messages are moved in:" : "Is messàgios cantzellados sunt tramudados in:",
+    "Save" : "Sarva",
+    "Connect" : "Connete",
     "Auto" : "Auto",
     "Name" : "Nùmene",
     "Password" : "Crae",
@@ -36,8 +38,6 @@ OC.L10N.register(
     "SMTP Port" : "Porta SMTP ",
     "SMTP User" : "Utente SMTP ",
     "SMTP Password" : "Crae SMTP",
-    "Save" : "Sarva",
-    "Connect" : "Connete",
     "Account settings" : "Cunfiguratzione de su contu",
     "Signature" : "Firma",
     "A signature is added to the text of new messages and replies." : "S'agiunghet una firma a su testu de is messàgios noos e de is respostas.",
@@ -54,6 +54,8 @@ OC.L10N.register(
     "Add alias" : "Agiunghe identidade",
     "Create alias" : "Crea identidade",
     "Cancel" : "Annulla",
+    "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus.",
+    "Could not update preference" : "No at fatu a agiornare sa preferèntzia",
     "Add mail account" : "Agiunghe contu de posta",
     "General" : "Generale",
     "Sorting" : "Assentende",
@@ -63,19 +65,19 @@ OC.L10N.register(
     "Register" : "Registra",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
     "Trusted senders" : "Imbiantes afidàbiles",
+    "About" : "In contu de",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Compose new message" : "Iscrie messàgiu nou",
     "Newer message" : "Messàgiu prus reghente",
     "Older message" : "Messàgiu prus betzu",
     "Toggle star" : "Ativa/disativa s'istella",
     "Toggle unread" : "Ativa/disativa non lèghidu",
-    "Archive" : "Cartella",
+    "Archive" : "Archìviu",
     "Delete" : "Cantzella",
     "Search" : "Chirca",
     "Send" : "Imbia",
     "Refresh" : "Agiorna",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus.",
-    "Could not update preference" : "No at fatu a agiornare sa preferèntzia",
+    "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
     "From" : "Dae",
     "Select account" : "Seletziona contu",
     "To" : "A",
@@ -95,15 +97,21 @@ OC.L10N.register(
     "Request a read receipt" : "Pedi una cunfirma de letura",
     "Encrypt message with Mailvelope" : "Tzifra messàgiu cun Mailvelope",
     "Enter a date" : "Inserta una data",
-    "Message {id} could not be found" : "Su messàgiu {id} no s'est pòdidu agatare",
+    "Choose" : "Sèbera",
     "Choose a file to add as attachment" : "Sèbera un'archìviu de agiùnghere comente alligongiadu",
     "Choose a file to share as a link" : "Sèbera un'archìviu de cumpartzire comente ligòngiu",
-    "Choose" : "Sèbera",
     "Confirm" : "Cunfirma",
     "Plain text" : "Testu simple",
     "Rich text" : "Testu formatadu",
     "No messages in this mailbox" : "Perunu messàgiu in custa casella de posta",
     "No messages" : "Perunu messàgiu",
+    "Blind copy recipients only" : "Isceti persones destinatàrias in còpia cuada",
+    "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
+    "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
+    "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
+    "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
+    "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
+    "Could not delete message" : "No at fatu a cantzellare su messàgiu",
     "Draft: " : "Brutacòpia:",
     "Unfavorite" : "Boga dae is preferidos",
     "Favorite" : "Preferidu",
@@ -119,13 +127,6 @@ OC.L10N.register(
     "Edit as new message" : "Modìfica comente messàgiu nou",
     "Create event" : "Crea eventu",
     "Create task" : "Crea faina",
-    "Blind copy recipients only" : "Isceti persones destinatàrias in còpia cuada",
-    "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
-    "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
-    "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
-    "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit",
-    "No trash mailbox configured" : "Peruna casella de àliga cunfigurada",
-    "Could not delete message" : "No at fatu a cantzellare su messàgiu",
     "Load more" : "Càrriga àteru",
     "_Mark {number} read_::_Mark {number} read_" : ["Marca {number} lèghidos","Marca {number} lèghidos"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Marca {number} no lèghidos","Marca {number} non lèghidos"],
@@ -135,43 +136,44 @@ OC.L10N.register(
     "_Move {number} thread_::_Move {number} threads_" : ["Tràmuda {number} dibatas","Tràmuda {number} dibatas"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Inoltra {number} comente alligongiados","Inoltra {number} comente alligongiadu"],
     "Report this bug" : "Signala cust'errore",
+    "Could not create event" : "No at fatu a creare s'eventu",
     "All day" : "Totu sa die",
     "Description" : "Descritzione",
     "Create" : "Crea",
-    "Could not create event" : "No at fatu a creare s'eventu",
     "Select" : "Seletziona",
     "Comment" : "Cummentu",
     "Accept" : "Atzeta",
     "Decline" : "Refuda",
     "More options" : "Àteras optziones",
+    "individual" : "individuale",
     "domain" : "domìniu",
     "Remove" : "Boga",
     "email" : "posta eletrònica",
     "Add internal address" : "Agiunghe indiritzu internu",
-    "individual" : "individuale",
     "Itinerary for {type} is not supported yet" : "S'itineràriu pro {type} no est ancora suportadu",
     "Could not open mailbox" : "No at fatu a abèrrere sa casella de posta",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Inditzizende is messàgios. S'at a pòdere istentare unu pagu de prus cun casellas de posta prus mannas.",
     "Choose target mailbox" : "Sèbera casella de posta de destinatzione",
     "No more submailboxes in here" : "Non b'at àteras suta-cartellas inoghe",
+    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
     "Important info" : "Informatzione importante",
     "Other" : "Àteru",
-    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Is messàgios s'ant a marcare in manera automàtica comente importantes in sa base de is messàgios cun is chi as tènnidu interatziones o chi si sunt marcados comente importantes. Fortzis a su cumintzu as a dèpere cambiare a manu s'importàntzia pro ddu imparare a su sistema, ma at a megiorare in su tempus.",
+    "Could not send mdn" : "No at fatu a imbiare mdn",
     "The sender of this message has asked to be notified when you read this message." : "Sa persone chi at imbiadu custu messàgiu at pedidu de no retzire notìficas cando dd'as a lèghere.",
     "Notify the sender" : "Notificare a sa persone chi imbiat",
     "You sent a read confirmation to the sender of this message." : "As imbiadu una cunfirma de letura a sa persone chi at imbiadu custu messàgiu.",
-    "Could not send mdn" : "No at fatu a imbiare mdn",
     "Forward" : "Torra a imbiare",
     "Move message" : "Tràmuda messàgiu",
+    "Translate" : "Borta",
     "View source" : "Visualiza sa fonte",
     "Download thread data for debugging" : "Iscàrriga is datos de sa dibata pro sa curretzione",
     "Message body" : "Corpus de su messàgiu",
+    "Unnamed" : "Chene nùmene",
+    "Embedded message" : "Messàgiu incorporadu ",
     "Choose a folder to store the attachment in" : "Sèbera una cartella in ue allogare s'alligongiadu",
     "Import into calendar" : "Importa in su calendàriu",
     "Download attachment" : "Iscàrriga alligongiadu",
     "Save to Files" : "Sarva in Archìvios",
-    "Unnamed" : "Chene nùmene",
-    "Embedded message" : "Messàgiu incorporadu ",
     "Choose a folder to store the attachments in" : "Sèbera una cartella in ue allogare is alligongiados",
     "Save all to Files" : "Sarva totu in Archìvios",
     "Download Zip" : "Iscàrriga Zip",
@@ -187,21 +189,27 @@ OC.L10N.register(
     "Moving" : "Tramudende",
     "Moving thread" : "Tramudende sa dibata",
     "Moving message" : "Tramudende su messàgiu",
+    "Loading …" : "Carrrighende …",
+    "Not supported by the server" : "No suportadu dae su serbidore",
+    "{usage} of {limit} used" : "{usage} de {limit} impreadu",
+    "Remove account" : "Boga·nche contu",
+    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Su contu pro {email} e is datos de posta eletrònica allogados in sa memòria temporànea s'ant a bogare dae Nextcloud, ma no dae su frunidore de posta eletrònica tuo.",
+    "Remove {email}" : "Boga•nche {email}",
     "Quota" : "Cuota",
     "Show only subscribed mailboxes" : "Mustra isceti casellas de posta sutascritas",
     "Add mailbox" : "Agiunghe casella de posta",
     "Saving" : "Sarvende",
     "Move up" : "Tràmuda fache a susu",
     "Move down" : "Tràmuda fache a bàsciu",
-    "Remove account" : "Boga·nche contu",
-    "Loading …" : "Carrrighende …",
-    "Not supported by the server" : "No suportadu dae su serbidore",
-    "{usage} of {limit} used" : "{usage} de {limit} impreadu",
-    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Su contu pro {email} e is datos de posta eletrònica allogados in sa memòria temporànea s'ant a bogare dae Nextcloud, ma no dae su frunidore de posta eletrònica tuo.",
-    "Remove {email}" : "Boga•nche {email}",
     "Show all subscribed mailboxes" : "Mustra totu is casellas de posta sutascritas",
     "Show all mailboxes" : "Mustra totu is casellas de posta",
     "Collapse mailboxes" : "Istringhe is casellas de posta",
+    "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
+    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} non lèghidos de {total}","{unread} unread of {total}"],
+    "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
+    "Delete mailbox" : "Cantzella casella de posta",
+    "Delete mailbox {name}" : "Cantzella casella de posta {name}",
+    "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
     "Mark all as read" : "Marca totu comente lèghidu",
     "Mark all messages of this mailbox as read" : "Marca totu is messàgios de custa casella de posta comente lèghidos",
     "Add submailbox" : "Agiunghe una sutacasella de posta",
@@ -209,21 +217,16 @@ OC.L10N.register(
     "Clear locally cached data, in case there are issues with synchronization." : "Lìmpia is datos locales allogados in sa memòria temporànea, s'in casu mai b'apant problemas cun sa sincronizatzione.",
     "Subscribed" : "Sutaiscritu",
     "Sync in background" : "Sincronizatzione in segunu pianu",
-    "Delete mailbox" : "Cantzella casella de posta",
-    "The mailbox and all messages in it will be deleted." : "Sa casella de posta e is messàgios chi cuntenet ant a èssere cantzellados.",
-    "Delete mailbox {name}" : "Cantzella casella de posta {name}",
-    "An error occurred, unable to rename the mailbox." : "B'at àpidu un'errore, no at fatu a torrare a numenare sa casella de posta.",
-    "_{total} message_::_{total} messages_" : ["{total} messàgios","{total} messàgios"],
     "New message" : "Messàgiu nou",
+    "Reply" : "Responde",
+    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
+    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Error sending your message" : "Errore in s'imbiu de su messàgiu",
     "Retry" : "Torra a proare",
     "Uploading attachments …" : "Carrighende alligongiadu ...",
     "Sending …" : "Imbiende ...",
     "Warning sending your message" : "Avisu in s'imbiu de su messàgiu",
     "Send anyway" : "Imbia a su pròpiu",
-    "Reply" : "Responde",
-    "No sent mailbox configured. Please pick one in the account settings." : "Nissuna casella de posta imbiada cunfigurada. Sèbera·nde una in sa cunfiguratzione de su contu.",
-    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Ses proende a imbiare a tropu persones in A e/o Cc. Cunsìdera de impreare Bcc pro cuare is indiritzos de is chi retzint.",
     "Message" : "Messàgiu",
     "Oh Snap!" : "Lampu!",
     "Contacts with this address" : "Cuntatos cun custu indiritzu",
@@ -232,13 +235,15 @@ OC.L10N.register(
     "Copy to clipboard" : "Còpia in is punta de billete",
     "Contact name …" : "Nùmene de su cuntatu ...",
     "Add" : "Agiunghe",
+    "Show less" : "Mustra prus pagu",
+    "Show more" : "Mustra de prus",
+    "Clear" : "Lìmpia",
     "Close" : "Serra",
     "Body" : "Corpus",
     "Date" : "Data",
     "Tags" : "Etichetas",
     "Select tags" : "Seletziona etichetas",
     "Last 7 days" : "Ùrtimas 7 dies",
-    "Clear" : "Lìmpia",
     "Sieve Port" : "Porta Sieve",
     "Custom" : "Personaliza",
     "Sieve User" : "Utente Sieve",
@@ -249,11 +254,11 @@ OC.L10N.register(
     "Save signature" : "Sarva firma",
     "Place signature above quoted text" : "Pone sa firma subra su testu tzitadu",
     "Saving new tag name …" : "Sarvende nùmene de eticheta nou...",
+    "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
     "Add tag" : "Agiunghe eticheta",
     "Saving tag …" : "Sarvende s'eticheta ...",
-    "An error occurred, unable to create the tag." : "B'at àpidu un'errore, no faghet a creare s'eticheta.",
-    "Not found" : "No agatadu",
     "Could not load your message thread" : "No at fatu a carrigare su messàgiu tuo in sa dibata",
+    "Not found" : "No agatadu",
     "Unsubscribe" : "Disiscrie·ti",
     "Reply to sender only" : "Responde isceti a chi at imbiadu",
     "Mark as unread" : "Marca comente non lèghidu",
@@ -261,23 +266,31 @@ OC.L10N.register(
     "Delete message" : "Cantzella messàgiu",
     "Message source" : "Fonte de su messàgiu",
     "Go to newest message" : "Bae a su messàgiu prus nou",
-    "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
     "Could not remove trusted sender {sender}" : "No at fatu a nche bogare s'imbiante afidàbile {sender}",
-    "(organizer)" : "(persona organizadora)",
+    "No senders are trusted at the moment." : "No b'at imbiantes afidàbiles in custu momentu.",
     "Untitled event" : "Eventu chene tìtulu",
+    "(organizer)" : "(persona organizadora)",
     "Import into {calendar}" : "Importa in {calendar}",
     "Event imported into {calendar}" : "Eventu importadu in {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Bolu {flightNr} dae {depAirport} a {arrAirport}",
     "Airplane" : "Aeroplanu",
     "Reservation {id}" : "Prenotatzione {id}",
-    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Bolu {flightNr} dae {depAirport} a {arrAirport}",
-    "Train" : "Trenu",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} dae {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Trenu dae {depStation} a {arrStation}",
+    "Train" : "Trenu",
     "New filter" : "Filtru nou",
     "New test" : "Proa noa",
     "Actions" : "Atziones",
     "New action" : "Atzione noa",
     "Priority" : "Prioridade",
+    "Successfully updated config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" agiornada in manera curreta",
+    "Error saving config" : "Errore sarvende sa cunfiguratzione",
+    "Saved config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" sarvada",
+    "Could not save provisioning setting" : "Impossìbile sarvare sa cunfiguratzione de frunidura",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Frunidura a is {count} contos fata in manera curreta. ","Frunidura a is {count} contos fata in manera curreta. "],
+    "There was an error when provisioning accounts." : "B'at àpidu un'errore in sa frunidura a is contos.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "S'at cantzelladu e bogadu sa frunidura a is contos pro \"{domain}\"",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore cantzellende e boghende•nde sa frunidura a is contos pro \"{domain}\"",
     "Mail app" : "Aplicatzione de posta",
     "The mail app allows users to read mails on their IMAP accounts." : "S'aplicatzione de posta permitit a is utentes de lèghere is messàgios de is contos IMAP issoro.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Inoghe podes agatare sa cunfiguratzione pro totu s'istàntzia. Is cunfiguratziones ispetzìficas de s'utente sunt in s'aplicatzione etotu (in bàsciu a manca).",
@@ -290,14 +303,6 @@ OC.L10N.register(
     "If you only want to provision one domain for all users, use the wildcard (*)." : "S'incasu cheres frunire isceti unu domìniu pro totu is utentes, imprea sa wild card (*).",
     "Add new config" : "Agiunghe cunfiguratzione noa",
     "Provision all accounts" : "Fruni a totu is contos",
-    "Successfully updated config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" agiornada in manera curreta",
-    "Error saving config" : "Errore sarvende sa cunfiguratzione",
-    "Saved config for \"{domain}\"" : "Cunfiguratzione pro \"{domain}\" sarvada",
-    "Could not save provisioning setting" : "Impossìbile sarvare sa cunfiguratzione de frunidura",
-    "There was an error when provisioning accounts." : "B'at àpidu un'errore in sa frunidura a is contos.",
-    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "S'at cantzelladu e bogadu sa frunidura a is contos pro \"{domain}\"",
-    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore cantzellende e boghende•nde sa frunidura a is contos pro \"{domain}\"",
-    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Frunidura a is {count} contos fata in manera curreta. ","Frunidura a is {count} contos fata in manera curreta. "],
     "Reset" : "Ripristina",
     "Client ID" : "ID cliente",
     "Client secret" : "Segretu de su cliente",
@@ -354,9 +359,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Incarca inoghe chi no ses torradu a deretare in manera automàtica intro de pagu segundos.",
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
-    "Continue to %s" : "Sighi in %s",
-    "Sieve filter rules" : "Règulas de filtru Sieve",
-    "Sieve filter server" : "Serbidore de filtru Sieve",
-    "Unselect" : "Deseletziona"
+    "Continue to %s" : "Sighi in %s"
 },
 "nplurals=2; plural=(n != 1);");
