@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "Personale",
     "Later" : "Më vonë",
     "Mail" : "Posta",
+    "Connecting" : "Duke u lidhur",
+    "Save" : "Ruaj",
+    "Connect" : "Lidhu",
+    "Password required" : "Kërkohet fjalëkalimi",
     "Name" : "Emri",
     "Mail address" : "Adresa e postës elektronike",
     "Password" : "Fjalëkalimi",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "Porta SMTP",
     "SMTP User" : "Përdoruesi i SMTP",
     "SMTP Password" : "Fjalëkalimi SMTP",
-    "Connecting" : "Duke u lidhur",
-    "Save" : "Ruaj",
-    "Connect" : "Lidhu",
-    "Password required" : "Kërkohet fjalëkalimi",
     "Aliases" : "Emërtimet",
     "Signature" : "Nënshkrimi",
     "Go back" : "Shko prapa",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "Add mail account" : "Shto llogarinë e postës elektronike",
     "General" : "Të përgjithshme",
     "Register" : "Regjistrohu",
+    "About" : "Rreth",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Newer message" : "Mesazhe më të reja",
     "Older message" : "Mesazhe më të vjetra",
@@ -46,8 +47,8 @@ OC.L10N.register(
     "Subject" : "Temë",
     "Upload attachment" : "Ngarko bashkëngjitje",
     "Add attachment from Files" : "Shto bashkëlidhje nga Dosjet",
-    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Choose" : "Zgjidhni",
+    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
     "Confirm" : "Konfirmo",
     "Unfavorite" : "Jo i/e preferuar",
     "Favorite" : "I/E Preferuar",
@@ -66,36 +67,37 @@ OC.L10N.register(
     "email" : "postë elektronike",
     "Other" : "Tjetër",
     "Forward" : "Përpara",
+    "Translate" : "Përkthe",
+    "Unnamed" : "E paemër",
     "Choose a folder to store the attachment in" : "Zgjidhni një dosje ku të depozitohet bashkëngjitja",
     "Import into calendar" : "Importo në kalendar",
     "Download attachment" : "Shkarko bashkëlidhjen",
     "Save to Files" : "Ruaje te Skedarët",
-    "Unnamed" : "E paemër",
     "Save all to Files" : "Ruaji të gjitha te Dosjet",
     "The images have been blocked to protect your privacy." : "Imazhet janë bllokuar për të mbrojtur privatësinë tuaj.",
     "Move" : "Zhvendos",
+    "Remove account" : "Fshij llogarinë",
     "Quota" : "Kuotë",
     "Saving" : "Duke u ruajtur!",
-    "Remove account" : "Fshij llogarinë",
     "Mark all as read" : "Shënoji krejt si të lexuar",
     "Rename" : "Riemërtoje",
     "Clear cache" : "Pastroje fshehtinën",
     "New message" : "Mesazh i ri",
+    "Reply" : "Përgjigju",
     "Retry" : "Riprovoni",
     "Sending …" : "Po dërgohet …",
-    "Reply" : "Përgjigju",
     "Message" : "Mesazh",
     "Copy to clipboard" : "Kopjo në dërrasë ",
     "Add" : "Shto",
+    "Clear" : "Pastro",
     "Close" : "Mbylleni",
     "Date" : "Data",
     "Tags" : "Etiketat",
     "Select tags" : "Përzgjidh etiketat",
-    "Clear" : "Pastro",
     "Custom" : "E përshtatur",
     "Delete tag" : "Fshi etiketën",
-    "Add tag" : "Shto etiketim",
     "Tag already exists" : "Etiketa ekziston",
+    "Add tag" : "Shto etiketim",
     "Mark as unread" : "Shënoje si të palexuar",
     "Mark as read" : "Shënoje si të lexuar",
     "Actions" : "Veprimet",
